@@ -2,10 +2,15 @@ import os
 import json
 import click
 import subprocess
+import requests
+from pathlib import Path
+from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
+WEBEX_ROOM = os.getenv("WEBEX_ROOM")
+WEBEX_TOKEN = os.getenv("WEBEX_TOKEN")
 
 class Network3Medusa():
     def __init__(self, command):
@@ -15,6 +20,8 @@ class Network3Medusa():
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
         self.add_file_to_hedera(raw_json)
+        if WEBEX_ROOM:
+            self.send_webex_notification()
         
     def py2output(self):
         self.output = subprocess.run(["python", "call_clid.py", self.command], capture_output=True)
@@ -26,14 +33,23 @@ class Network3Medusa():
         fileContents = raw_json
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(client)
         print("nodeId: ",  resp.nodeId.toString())
+        self.nodeId = resp.nodeId.toString()
         receipt = resp.getReceipt(client)
-        fileId = receipt.fileId
-        print("file: ",  fileId.toString())
+        self.fileId = receipt.fileId
+        print("file: ",  self.fileId.toString())
         query = FileContentsQuery()
-        contents = query.setFileId(fileId).execute(client)
+        contents = query.setFileId(self.fileId).execute(client)
         json_contents = json.loads(contents.toStringUtf8())
         print(json_contents)        
 
+    def send_webex_notification(self):
+        template_dir = Path(__file__).resolve().parent
+        env = Environment(loader=FileSystemLoader(str(template_dir)))
+        adaptive_card_template = env.get_template('sent_to_hedera.j2')
+        adataptive_card_output = adaptive_card_template.render(roomid = WEBEX_ROOM, command = self.command, nodeid = self.nodeId, fileid = self.fileId.toString())
+        webex_adaptive_card_response = requests.post('https://webexapis.com/v1/messages', data=adataptive_card_output, headers={"Content-Type": "application/json", "Authorization": f"Bearer { WEBEX_TOKEN }" })
+        print('The POST to WebEx had a response code of ' + str(webex_adaptive_card_response.status_code) + 'due to' + webex_adaptive_card_response.reason)
+
 @click.command()
 @click.option('--command',
     prompt='Command',
